Supvisors status

Memory occupation

Memory Statistics
mem | Occ % | Mean % | Slope % | SD %
--- | --- | --- | --- | ---
-- | -- | -- | --

CPU loading

Processor Statistics
# | Last % | Mean % | Slope % | SD %
--- | --- | --- | --- | ---
cpu#0 | -- | -- | -- | --

Network activity

Network Statistics
Interface | Rx/Tx | Last kbit/s | Mean kbit/s | Slope % | SD kbit/s
--- | --- | --- | --- | --- | ---
eth# | -- | -- | -- | -- | --